import { ComponentPropsWithoutRef } from 'react';
import { ButtonSizes, Variant } from '../../@types';
interface IButtonCommonProps extends ComponentPropsWithoutRef<'button'> {
    /**
     * Defines if the button is disabled
     */
    disabled?: boolean;
    /**
     * Defines the focus offset color between button and ring
     */
    focusOffsetColor?: string;
    /**
     * Defines the icon style
     */
    iconClass?: string;
}
declare type IButtonConditionalProps = 
/**
 * Icon only button
 */
{
    /**
     * Defines the background & text color of the button
     */
    variant?: Exclude<keyof typeof Variant, 'ghost'>;
    /**
     * Defines icon only button
     */
    isOnlyIcon: true;
    /**
     * Defines the dimensions of the icon button for all variants
     */
    size?: keyof typeof ButtonSizes;
    /**
     * Defines icon type
     */
    iconType?: string;
}
/**
 * 'Ghost' button
 */
 | {
    /**
     * Defines the background & text color of the 'ghost' button
     */
    variant: 'ghost';
    /**
     * Defines icon only button
     */
    isOnlyIcon?: boolean;
    /**
     * Defines the dimensions of the icon button for all variants
     */
    size?: 'md';
    /**
     * Defines icon type
     */
    iconType?: string;
}
/**
 * Regular button
 */
 | {
    /**
     * Defines icon only button
     */
    isOnlyIcon?: never;
    /**
     * Defines the background & text color of the button
     */
    variant?: Exclude<keyof typeof Variant, 'ghost'>;
    /**
     * You can not change 'size' for regular button. 'size' by default 'lg'
     */
    size?: never;
    /**
     * You can not define 'isOnlyIcon' with regular button
     */
    iconType?: string;
};
export declare type IButtonProps = IButtonCommonProps & IButtonConditionalProps;
export {};
//# sourceMappingURL=types.d.ts.map